package picontrol;

// Imports
import java.util.ArrayList;

/**
 * Automatic: This class implements the automatic operation mode, the DFA (Deterministic Finite Automata).
 *
 * This class stores the different states in which the system can be, and also, the current state.
 *
 */
public class Automatic {
    // Attributes

    private int numStates; // Number of states.
    private ArrayList<AutomaticState> listState; // Array list with all the states.
    private AutomaticState currentState; // Current state.

    // Constructors
    // ------------
    /**
     * Constructor without parameters.
     */
    public Automatic() {
        listState = new ArrayList<>();
        currentState = new AutomaticState();
    }

    /**
     * Constructor with number of states.
     *
     * @param numStates number of states that owns the system.
     */
    public Automatic(int numStates) {
        this.numStates = numStates;
        listState = new ArrayList<>(numStates);
        currentState = new AutomaticState();
    }

    /**
     * getNumStates: return the number of States.
     *
     * @return number of states that owns the system.
     */
    public int getNumStates() {
        return numStates;
    }

    /**
     * setNumStates: set the number of States.
     *
     * @param numStates number of states that owns the system.
     *
     */
    public void setNumStates(int numStates) {
        this.numStates = numStates;
    }

    /**
     * getListState: return the list of States.
     *
     * @return the listState
     */
    public ArrayList<AutomaticState> getListState() {
        return listState;
    }

    /**
     * setListState: set the list of States.
     *
     * @param listState list of states to set
     *
     */
    public void setListState(ArrayList<AutomaticState> listState) {
        this.listState = listState;
    }

    /**
     * addListStates: add a State to the list of States.
     *
     * @param state to add to the list of states.
     */
    public void addListStates(AutomaticState state) {
        this.listState.add(state);
    }

    /**
     * updateListStates: update a State to the list of States.
     *
     * @param state to add to the list of states.
     * @param pos position to set the state.
     */
    public void updateListStates(AutomaticState state, int pos) {
        if (pos <= listState.size()) {
            this.listState.set(pos, state);
        }
    }

    /**
     * getState: returns the state that is in the indicated position.
     *
     * @param pos: position to get the state.
     *
     * @return AutomaticState placed on indicated position.
     */
    public AutomaticState getState(int pos) {
        if (pos > this.listState.size()) {
            return null;
        } else {
            return this.listState.get(pos);
        }
    }

    /**
     * getState: Return the state whose name matches the past as parameter.
     *
     * @param name to search.
     *
     * @return the state with the name passed as parameter.
     */
    public AutomaticState getState(String name) {
        for (AutomaticState as : listState) {
            if (as.getName().equals(name)) {
                return as;
            }
        }
        return null;
    }

    /**
     * getCurrentState: return the current State.
     *
     * @return the current state
     */
    public AutomaticState getCurrentState() {
        return currentState;
    }

    /**
     * setCurrentState: set the current State of the system.
     *
     * @param currentState State to set.
     */
    public void setCurrentState(AutomaticState currentState) {
        this.currentState = currentState;
    }

    /**
     * toString
     *
     * @return string with the object
     */
    @Override
    public String toString() {
        return "automatic{" + "numStatus=" + numStates + ", \nlistState=" + listState + "}\n";
    }
}
