package picontrol;

/**
 * AutomaticRule: This class implements the rules that have to fulfilled to change from the current
 * state to another.
 *
 * I have defined two types of rules: P for Permanence and C for Change
 *
 * Permanence: rules that apply on the current state.
 *
 * Change: rules that decide whether to change newStatus, and which.
 *
 */
public class AutomaticRule {
    // Attributes

    private String name; // Name of the rule
    private String ruleType; // Type of rule (C or P)
    private String server; // Name Server
    private String typeSensor; // Type of sensor Input or Output
    private String nameSensor; // Name of the sensor
    private String value; // Value of the sensor
    private String newState; // New state that apply this rule
    private String comment; // Comment

    /**
     * Constructors
     */
    public AutomaticRule() {
        // Initializing attributes
        this.name = "";
        this.ruleType = "";
        this.server = "";
        this.typeSensor = "";
        this.nameSensor = "";
        this.value = "";
        this.newState = "";
        this.comment = "";
    }

    /**
     * getName: return the name of the rule.
     *
     * @return a string with the name of the rule
     */
    public String getName() {
        return name;
    }

    /**
     * setName: set the name of the rule.
     *
     * @param name: string with the name of the rule.
     *
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * getRuleType: return the type of rule.
     *
     * @return a string with the type of rule
     */
    public String getRuleType() {
        return ruleType;
    }

    /**
     * setRuleType:
     *
     * @param ruleType the string with ruleType to set
     */
    public void setRuleType(String ruleType) {
        this.ruleType = ruleType;
    }

    /**
     * getServer: get the server to apply the rule.
     *
     * @return the server
     */
    public String getServer() {
        return server;
    }

    /**
     * setServer: Set the server to apply the rule.
     *
     * @param server the server to set
     */
    public void setServer(String server) {
        this.server = server;
    }

    /**
     * @return the typeSensor
     */
    public String getTypeSensor() {
        return typeSensor;
    }

    /**
     * @param typeSensor
     *                   the typeSensor to set
     */
    public void setTypeSensor(String typeSensor) {
        this.typeSensor = typeSensor;
    }

    /**
     * @return the nameSensor
     */
    public String getNameSensor() {
        return nameSensor;
    }

    /**
     * @param nameSensor
     *                   the nameSensor to set
     */
    public void setNameSensor(String nameSensor) {
        this.nameSensor = nameSensor;
    }

    /**
     * @return the value
     */
    public String getValue() {
        return value;
    }

    /**
     * @param value
     *              the value to set
     */
    public void setValue(String value) {
        this.value = value;
    }

    /**
     * @return the newState
     */
    public String getNewState() {
        return newState;
    }

    /**
     * @param newState
     *                 the newState to set
     */
    public void setNewState(String newState) {
        this.newState = newState;
    }

    /**
     * @return the comment
     */
    public String getComment() {
        return comment;
    }

    /**
     * @param comment
     *                the comment to set
     */
    public void setComment(String comment) {
        this.comment = comment;
    }

    /**
     * toString: return a string with the automatic rule
     *
     * @return string with the rule
     */
    @Override
    public String toString() {
        return "AutomaticRule{" + "name=" + name + ", ruleType=" + ruleType + ", Server=" + server + ", typeSensor="
                + typeSensor + ", nameSensor=" + nameSensor + ", value=" + value + ", newStatus=" + newState
                + ", comment=" + comment + "}\n";
    }
}
