package picontrol;
// Imports

import java.util.ArrayList;

/**
 *
 * AutomaticState: This class implements one state, and all the rules that apply
 * in this state.
 *
 * 
 */
public class AutomaticState {

    // Attributes
    private String name; // Name of the state
    private int numRules; // Number of rules on this state
    private ArrayList<AutomaticRule> listRules; // List of rules

    /**
     * Constructors
     */
    /**
     * Constructor without parameters
     */
    public AutomaticState() {
        this.listRules = new ArrayList<>();
    }

    /**
     * Constructor with defined number of rules
     *
     * @param numRules number of rules of this state
     */
    public AutomaticState(int numRules) {
        this.listRules = new ArrayList<>(numRules);
        this.numRules = numRules;
    }

    /**
     * Constructor with name and defined number of rules
     *
     * @param name name of the state
     * @param numRules number of rules of this state
     */
    public AutomaticState(String name, int numRules) {
        this.listRules = new ArrayList<>(numRules);
        this.numRules = numRules;
        this.name = name;
    }

    /**
     * getName: returns the name of the rule
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * setName: set the name of the rule
     *
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * getNumRules: return the number of rules on the state
     *
     * @return the numRules
     */
    public int getNumRules() {
        return numRules;
    }

    /**
     * setNumRules: set the number of rules on the state
     *
     * @param numRules the numRules to set
     */
    public void setNumRules(int numRules) {
        this.numRules = numRules;
    }

    /**
     * getListRules: return the list of rules on the state
     *
     * @return the listRules
     */
    public ArrayList<AutomaticRule> getListRules() {
        return listRules;
    }

    /**
     * updateListRules: add a rule to the list of rules
     *
     * @param rule to add to the list of rules
     */
    public void addListRules(AutomaticRule rule) {
        this.listRules.add(rule);
    }

    /**
     * updateListRules: update the rule in the position specified
     *
     * @param rule Rule to update
     * @param pos Position in the list 
     */
    public void updateListRules(AutomaticRule rule, int pos) {
        this.listRules.set(pos, rule);
    }

    /**
     * getRule: return the rule on the specified position
     *
     * @param pos position on the list of rules
     *
     * @return the rule
     */
    public AutomaticRule getRule(int pos) {
        if (pos > this.listRules.size()) {
            return null;
        } else {
            return this.listRules.get(pos);
        }
    }

    /**
     * getRule: return the rule with the specified name
     *
     * @param name of the rule to search.
     *
     * @return the rule
     */
    public AutomaticRule getRule(String name) {
        for (AutomaticRule ar : listRules) {
            if (ar.getName().equals(name)) {
                return ar;
            }
        }
        return null;
    }

    /**
     * setListRules: set the list of rules
     *
     * @param listRules the listRules to set
     */
    public void setListRules(ArrayList<AutomaticRule> listRules) {
        this.listRules = listRules;
    }

    /**
     * toString: return the string with the current state
     *
     * @return string with the state
     */
    @Override
    public String toString() {
        return "Automatic State{" + "name=" + name
                + ", numRules=" + numRules
                + ",\n listRules=" + listRules + "}\n";
    }
}
