package picontrol;

/**
 * Constants: this class implements the constants values for the system.
 *
 *
 */
public final class Constants {

    /*
     ********************************************************
     *
     * Constants
     *
     *******************************************************
     */
    /**
     * SERVER_NAME: Name of the servers
     */
    public static final String SERVER_NAME = "PiServer"; // Server Names

    /**
     * CLIENT_NAME: Name of the client
     */
    public static final String CLIENT_NAME = "RPiControl"; // Server Names
    //
    // ---------------------------------------------------------------------------------------------------------
    //

    // HTTP protocol strings
    /**
     * USER_AGENT: String who identify the application type.
     */
    public static final String USER_AGENT = "PiSolar/1.0"; // Mozilla/5.0
    /**
     * PROTOCOL: String who identify the protocol.
     */
    public static final String PROTOCOL = "http://";

    /**
     * PATH: Home path.
     */
    public static final String PATH = "/home/pi/";

    /**
     * CONFIG_PATH: Path for search the configuration files.
     */
    public static final String CONFIG_PATH = "/home/pi/.config/piSolar/";

    // Name of the configuration files
    /**
     *
     */
    public static final String CONFIG_SERVER_FILENAME = "rpi.config";

    /**
     *
     */
    public static final String CONFIG_CLIENT_FILENAME = "client.config";

    /**
     *
     */
    public static final String CONFIG_MANUAL_FILENAME = "manual.config";

    /**
     *
     */
    public static final String CONFIG_AUTOMATIC_FILENAME = "automatic.config";

    /**
     *
     */
    public static final String CONFIG_EMAIL_FILENAME = "mail.config";

    /**
     *
     */
    public static final String CONFIG_LOG_PROPERTIES_XML = "log4j2.xml";

    /**
     * INITIAL_STATE: Initial State for the automata.
     */
    public static final String INITIAL_STATE = "Status1";

    // Name of temperature sensors
    /**
     * SENSOR_TEMP_SOLAR: Name of sensor of temperature into termoshiphon.
     */
    public static final String SENSOR_TEMP_SOLAR = "SensorT";

    /**
     * SENSOR_TEMP_AUX: Name of sensor of auxiliary thermo-accumulator.
     */
    public static final String SENSOR_TEMP_AUX = "SensorA";

    /**
     * SENSOR_TEMP_EXT: Name of sensor of exterior temperature.
     */
    public static final String SENSOR_TEMP_EXT = "SensorE";

    /**
     * CONNECTION_ERROR: Enumerator with the connection errors
     */
    public static enum CONNECTION_ERROR {

        /**
         *
         */
        NO_ERROR,
        /**
         *
         */
        TIMEOUT_ERROR,
        /**
         *
         */
        IO_ERROR,
        /**
         *
         */
        POST_ERROR,
        /**
         *
         */
        GET_ERROR,
        /**
         *
         */
        COMMAND_ERROR
    }

    /**
     * TYPE_ORDER: Enumerator with the type of manual orders
     */
    public static String TYPE_ORDER[] = {
        "RASPBERRY",
        "DEVICE"
    };

    /**
     * WORKING_MODE: Enumerator with the working modes
     */
    public static enum WORKING_MODE {

        /**
         *
         */
        AUTOMATIC,
        /**
         *
         */
        MANUAL
    }

    /**
     * MANUAL_ORDERS_DEVICE: array with the valid device manual orders
     */
    public static String MANUAL_ORDERS_DEVICE[] = {
        "ON",
        "OFF",
        "AUTO"
    };

    /**
     * MANUAL_ORDERS_GLOBAL: array with the valid manual orders
     */
    public static String MANUAL_ORDERS_GLOBAL[] = {
        "SHUTDOWN",
        "REBOOT"
    };

    //
    // DataBase MariaDB/MySQL Constants
    //
    // Database connections
    /**
     *
     */
    public static final String DB_DSN = "jdbc:mariadb";

    /**
     *
     */
    public static final String DB_NAME = "SolarPi";

    /**
     *
     */
    public static final String DB_HOST = "10.218.79.240:3306";
    // or public static final String DB_HOST = "localhost:3306";
    // or public static final String DB_HOST = "127.0.0.1:3306";

    /**
     *
     */
    public static final String DB_USER = "user";

    /**
     *
     */
    public static final String DB_PASS = "piSolar";

    // Tables & fields names definition
    /**
     *
     */
    public static final String DB_TBL_TEMPERATURE = "temperature"; // Table for store the temperature value

    /**
     *
     */
    public static final String DB_TBL_MANUAL_ORDERS = "manual";

    /**
     *
     */
    public static final String DB_TBL_STATUS = "status"; // 

    /**
     *
     */
    public static final String DB_FIELD_MANUAL_ORDER_PROCESSED = "process";

    // SQL orders
    /**
     * SQL_MANUAL_ORDERS_GET: SQL query to get the unprocessed manual orders.
     *
     * If this order affect one device, this order remain until it's manually.
     * changed, or set to automatic mode
     */
    public static final String SQL_MANUAL_ORDERS_GET
            = "SELECT * FROM " + DB_TBL_MANUAL_ORDERS + " WHERE process=0";

    /**
     * SQL_MANUAL_ORDERS_COUNT: get the number of unprocessed manual orders.
     *
     */
    public static final String SQL_MANUAL_ORDERS_COUNT
            = "SELECT COUNT(*) FROM " + DB_TBL_MANUAL_ORDERS + " WHERE process = 0";

    /**
     * SQL_MANUAL_ORDERS_UPDATE: Query to update the status of manual order.
     * From unprocessed to processed.
     */
    public static final String SQL_MANUAL_ORDERS_UPDATE
            = "UPDATE " + DB_TBL_MANUAL_ORDERS + " SET process = 1, date = ? WHERE id = ?;";

    /**
     * SQL_MANUAL_ORDERS_SEARCH: Query to find a specified manual order.
     */
    public static final String SQL_MANUAL_ORDERS_SEARCH
            = "SELECT Id FROM " + DB_TBL_MANUAL_ORDERS
            + " WHERE server = ? AND device = ? AND type = ? AND process=0";

    /**
     * SQL_TEMPERATURE_INSERT: Query to insert the temperatures in the database.
     */
    public static final String SQL_TEMPERATURE_INSERT
            = "INSERT INTO " + DB_TBL_TEMPERATURE + " (tempSolar, tempExt) VALUES (?, ?)";

    /**
     * SQL_STATUS_INSERT: Query to insert the current status in the database.
     */
    public static final String SQL_STATUS_INSERT
            = "INSERT INTO " + DB_TBL_STATUS
            + " (server, name, mode, pinname, value, statusName)"
            + " VALUES (?, ?, ?, ?, ?, ?);";

    /**
     * SQL_STATUS_UPDATE: Query to update the status to a new value.
     */
    public static final String SQL_STATUS_UPDATE
            = "UPDATE " + DB_TBL_STATUS + " SET value = ?, date = ? WHERE Id = ?;";

    /**
     * SQL_STATUS_SEARCH: Query to search a specific value from the status.
     */
    public static final String SQL_STATUS_SEARCH_ID
            = "SELECT Id FROM " + DB_TBL_STATUS + " WHERE server = ? AND name = ?;";

    /**
     * SQL_STATUS_EXISTS: SQL query to check if exist some status stored in the
     * database.
     */
    public static final String SQL_STATUS_EXISTS
            = "SELECT * FROM " + DB_TBL_STATUS + ";";

    /**
     * SQL_STATUS_CLEAN: Query to clean (truncate) the status database.
     */
    public static final String SQL_STATUS_CLEAN
            = "TRUNCATE " + DB_TBL_STATUS + ";";

    /**
     * SQL_GET_STATUS_NUMBER: Query to get the number of rows of a status.
     */
    public static final String SQL_STATUS_VERIFY_NAME
            = "SELECT count(*) FROM " + DB_TBL_STATUS + " WHERE statusName = ?";
}
