package picontrol;

import java.sql.Connection;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 * PiControl: main class who implements the Raspberry who control the system
 *
 *
 */
public class PiControl {

    /*
     * ************************************************************************
     *
     * Declaration of global objects and variables
     *
     **************************************************************************/
    // Object Client, who store all info about system
    private static Client client;
    // Objects wit the message request and response
    static Response objResponse;
    static Request objRequest;
    // Object who represent the current currentStatus of the system
    static Status currentStatus;
    // Object who represent the automatic used for the automatic mode
    static Automatic automatic;
    // SQLUtils Database connection
    static Connection sqlConnection;
    // Java logger
    static final Logger logger = LogManager.getLogger(picontrol.PiControl.class.getName());

    /**
     * main
     *
     * @param args for the main.. Not used
     */
    public static void main(String[] args) {
        // Declaration
        Constants.WORKING_MODE mode; // Automatic or manual mode.
        boolean endClient; // End the control?

        // Initialization
        endClient = false;

        // Instantiate the object request & response from/to servers
        objResponse = new Response();
        objRequest = new Request();

        logger.warn("Starting PiClient");

        // ---------------------------------------------------------------------------------
        logger.trace("Initializating PiControl");

        // Instantiate new client control
        client = new Client();

        // Get control configuration from file
        logger.trace("Read client configuration from file.");
        client = Processing.getClientConfig(client);

        // Number of theoretical servers in the net
        int numServers = client.getNumServers();

        // Initialization servers IP address
        logger.trace("Initializating server configuration.");
        client = Processing.initServers(client);

        // Create global Status
        logger.trace("Initializating global status.");
        client.initStatus();
        currentStatus = client.getStatus();
        currentStatus.setNumProcessors(numServers + 1);

        // Initialization of automatic class
        logger.trace("Initializating automatic automata configuration.");
        automatic = Processing.readAutomaticConfig(client);
        client.setAutomatic(automatic);

        // Initialize SQL Connection
        logger.trace("Initializating database connection.");
        sqlConnection = SQLUtils.dbConnect(sqlConnection);

        // Wait for all servers go online,
        // Also update their data, and the currentStatus!!
        logger.trace("Waiting for all servers online, and initializating their status.");
        Communication.waitForAllServersOnline(client);
        // Repeat forever or Client exit by manual request
        while (!endClient) {
            try {
                // Wait specified time. I don't need many speed
                // Sleep work with miliseconds.
                Thread.sleep(client.getConfigTimeWait());
                // Detect working mode
                mode = Processing.detectMode(sqlConnection);
                if (mode == Constants.WORKING_MODE.AUTOMATIC) {
                    logger.trace("Running in Automatic mode!!!");
                    Processing.doAutomaticMode(client);
                } else {
                    // Manual mode
                    logger.trace("Running in Manual mode!!!");
                    endClient = Processing.doManualMode(client, sqlConnection);
                }
                // Update status in the servers
                Processing.updateStatusInServers(client);
                // Store the current status and the temp in the database
                logger.trace("Storing status in database!!!");
                SQLUtils.dbStoreStatus(client, sqlConnection);
                // 
            } // End While
            catch (InterruptedException ex) {
                logger.error("Error Waiting!!! " + ex.getMessage());
            }
        }
        // End server
        logger.warn("End of PiClient");
        System.exit(0);
    }
}
