package picontrol;

import java.util.ArrayList;

/**
 * Processor: this class implements a the logic part of a server on the network.
 *
 *
 */
public class Processor {

    private String name; // Identifier name
    private String ip; // IP address
    private String type; // Client or Server
    private boolean online; // Is online?
    private ArrayList<Peripheral> listPeripherals;

    /**
     * Processor: constructor without parameters.
     */
    public Processor() {
        this.listPeripherals = new ArrayList<>();
    }

    /**
     * Processor: constructor with parameters.
     *
     * @param name   name of the processor (logic part of the server)
     * @param ip     String with the IP address of the server
     * @param online boolean to indicate if the server is on line.
     */
    public Processor(String name, String ip, boolean online) {
        this.listPeripherals = new ArrayList<>();
        this.name = name;
        this.ip = ip;
        this.online = online;
    }

    /**
     * getName: return the name of the processor (Logical Server)
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * setName: set the name of the processor (Logical Server)
     *
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * getIp: return the IP address of the processor (Logical Server)
     *
     * @return the IP
     */
    public String getIp() {
        return ip;
    }

    /**
     * stIp: set the IP address of the processor (Logical Server)
     *
     * @param ip
     *           the ip to set
     */
    public void setIp(String ip) {
        this.ip = ip;
    }

    /**
     * isOnline: return if the processor (Logical Server) is online
     *
     * @return the online
     */
    public boolean isOnline() {
        return online;
    }

    /**
     * setline: mark a processor (Logical Server) online
     *
     * @param online the online to set
     */
    public void setOnline(boolean online) {
        this.online = online;
    }

    /**
     * getlistPeripherals: return the list of peripherals of this processor
     *
     * @return the listPeripherals
     */
    public ArrayList<Peripheral> getlistPeripherals() {
        return listPeripherals;
    }

    /**
     * setListPeripherals: set the list of peripherals of this processor
     *
     * @param listPeripherals the listPeripherals to set
     */
    public void setListPeripherals(ArrayList<Peripheral> listPeripherals) {
        this.listPeripherals = listPeripherals;
    }

    /**
     * addPeripheral: add a peripheral to this processor.
     *
     * @param peripheral Peripheral to add.
     */
    public void addPeripheral(Peripheral peripheral) {
        this.listPeripherals.add(peripheral);
    }

    /**
     * updatePeripheral: update the peripheral in specified position
     *
     * @param peripheral Peripheral to update.
     * @param pos        Position in the list of peripherals to update.
     */
    public void updatePeripheral(Peripheral peripheral, int pos) {
        this.listPeripherals.set(pos, peripheral);
    }

    /**
     * getPeripheral: return the peripheral with specified name.
     *
     * @param name String with the name of the peripheral to search.
     *
     * @return the peripheral with the specified name.
     */
    public Peripheral getPeripheral(String name) {
        for (Peripheral p : listPeripherals) {
            if (p.getName().equals(name)) {
                return p;
            }
        }
        return null;
    }

    /**
     * getPeripheral: return the peripheral in specified position
     *
     * @param pos Position in the list of peripherals
     *
     * @return the peripheral
     */
    public Peripheral getPeripheral(int pos) {
        if (listPeripherals.size() > pos) {
            return this.listPeripherals.get(pos);
        } else {
            return null;
        }
    }

    /**
     * getType: return the type of processor
     *
     * @return the type
     */
    public String getType() {
        return type;
    }

    /**
     * setType: set the type of processor
     *
     * @param type * the type to set
     */
    public void setType(String type) {
        this.type = type;
    }

    /**
     * toString: return the string with the processor values
     *
     * @return the string with the processor values
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        if (isOnline()) {
            sb.append("Processor -> ").append(getName()).append(", working as ").append(getType()).append(".\n");
            for (int i = 0; i < listPeripherals.size(); i++) {
                sb.append(getPeripheral(i).toString());
            }
            sb.append("---------------------\n");
        }
        return sb.toString();
    }
}
