package picontrol;

/**
 * Response: This class implements a server response.
 *
 *
 */
public class Response {

    // Attributes
    private Constants.CONNECTION_ERROR errorCode; // Error code in the connection or in the command
    private String message;

    /**
     * Response: Constructor without parameters
     */
    public Response() {
        this.errorCode = Constants.CONNECTION_ERROR.NO_ERROR;
        this.message = "";
    }

    /**
     * Response: Constructor with message and error code
     *
     * @param code: code of the error to set
     * @param msg:  message to set in the response
     */
    public Response(Constants.CONNECTION_ERROR code, String msg) {
        this.errorCode = code;
        this.message = msg;
    }

    /**
     * Response: Constructor with message
     *
     * @param msg: message to set in the response
     */
    public Response(String msg) {
        this.errorCode = Constants.CONNECTION_ERROR.NO_ERROR;
        this.message = msg;
    }

    /**
     * Response: Constructor with error code
     *
     * @param code: code of the error to set
     */
    public Response(Constants.CONNECTION_ERROR code) {
        this.errorCode = code;
        this.message = "";
    }

    /**
     * getErrorCode: return the error code received in the response.
     *
     * @return the errorCode
     */
    public Constants.CONNECTION_ERROR getErrorCode() {
        return errorCode;
    }

    /**
     * setErrorCode: set the initial error code.
     *
     * @param errorCode the errorCode to set
     */
    public void setErrorCode(Constants.CONNECTION_ERROR errorCode) {
        this.errorCode = errorCode;
    }

    /**
     * getMessage: return the message from the response
     *
     * @return the message
     */
    public String getMessage() {
        return message;
    }

    /**
     * setMessage: set the message into the response
     *
     * @param message the message to set
     */
    public void setMessage(String message) {
        this.message = message;
    }

    /**
     * toString:
     *
     * @return String with the response
     */
    @Override
    public String toString() {
        return super.toString();
    }
}
