package picontrol;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.PasswordAuthentication;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 * SendMail: this class implements the methods to send a email.
 *
 * It uses the JavaMail Library
 *
 * 
 */
public class SendMail {

    // Logger for logs and messages
    static final Logger logger = LogManager.getLogger(picontrol.SendMail.class.getName());

    /**
     * senEmail: this method send the specified string to a pre-configured email address, 
     * read from configuration file.
     * 
     * @param msg String to send in the email.
     */
    public static void sendMail(String msg) {
        // Declarations
        final String username;
        final String password;
        final String receiver;
        Properties properties;
        Message message;
        String[] config;

       
        // Read username, password and destinatary from file
        config = readEmailConfig();
        username = config[0];
        password = config[1];
        receiver = config[2];

        // Prepare the properties (pair key, value)
        properties = new Properties();
        properties.put("mail.smtp.auth", "true");
        properties.put("mail.smtp.starttls.enable", "true");
        properties.put("mail.smtp.host", "smtp.gmail.com");
        properties.put("mail.smtp.port", "587");

        // Get the connection session
        Session session = Session.getInstance(properties, new javax.mail.Authenticator() {
            @Override
            protected PasswordAuthentication getPasswordAuthentication() {
                return new PasswordAuthentication(username, password);
            }
        });

        try {
            // Prepare the message MIME
            message = new MimeMessage(session);
            message.setFrom(new InternetAddress(username));
            message.setRecipients(Message.RecipientType.TO, InternetAddress.parse(receiver));
            message.setSubject("Solar Pi System Error");
            message.setText(msg);
            // Send the message
            Transport.send(message);
            logger.trace("Send email!!");
        } catch (MessagingException e) {
            logger.error("Error sending email!!\n" + e.getMessage());
        }
    }

    /**
     * readEmailConfig: read the email configuration from a file.
     *
     * @return a string array with the configuration: username, password and receiver email
     */
    public static String[] readEmailConfig() {
        // TO-DO EXTRA: Read email configuration from database!!!
        // Declarations
        Properties properties;
        String filename;            // Config File Name
        String[] config;            // Email configuration
        // Inicialization
        properties = new Properties();
        config = new String[3];
        filename = Constants.CONFIG_PATH + Constants.CONFIG_EMAIL_FILENAME;

        try {
            InputStream is = new FileInputStream(filename);
            // Load properties file
            properties.load(is);
            // Read properties and set values
            config[0] = properties.getProperty("username");
            config[1] = properties.getProperty("password");
            config[2] = properties.getProperty("receiver");
        } catch (FileNotFoundException fnfe) {
            logger.fatal("Error Reading config file: " + filename + "\nError" + fnfe.getMessage());
            System.exit(-1);
        } catch (IOException ioe) {
            logger.fatal("Error " + ioe.getMessage());
            System.exit(-1);
        }
        return config;
    }
}