package picontrol;

import com.pi4j.system.SystemInfo;
import java.io.IOException;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 *
 * Utilities: some utilities class
 *
 *
 */
public final class Utilities {

    // Logger for logs and messages
    static final Logger logger = LogManager.getLogger(picontrol.Utilities.class.getName());

    /**
     * CleanString: clean spaces from begin and end of a string. It also
     * replaces consecutive spaces for only one
     *
     * @param msg String to clean
     *
     * @return String cleaned.
     */
    public static String CleanString(String msg) {
        String cleaned = msg;
        try {
            cleaned = cleaned.replaceAll(" +", " ").trim();
        } catch (Exception e) {
            logger.fatal("Error reading text from configuration file!!");
            System.exit(-1);
        }
        return cleaned;
    }

    /**
     * Welcome: Shows the welcome message
     *
     * @param client to show the welcome message.
     */
    public static void Welcome(Client client) {
        // Welcome message
        System.out.println("  Raspberry Solar Control  ");
        System.out.println("---------------------------");
        System.out.println("");
        System.out.println("");
        System.out.println(client.getIdentifier() + " waiting on "
                + client.getIpAddress() + ":" + client.getPort());
        System.out.println("");
        System.out.println(client);
        System.out.println("Num Servers:" + client.getNumServers());
        System.out.println("-----------------------------------------\n");
    }

    /**
     * getHost: Get the Host part from a String IP address. I guest a /24
     * network
     *
     * @param address: IP Address
     *
     * @return String with the host
     */
    public static int getHost(String address) {
        return Integer.parseInt(address.substring(address.lastIndexOf(".") + 1));
    }

    /**
     * getNetwork: Get the network from a String IP address. I guest a /24
     * network
     *
     * @param address IP address.
     *
     * @return String with the network
     */
    public static String getNetwork(String address) {
        return address.substring(0, address.lastIndexOf("."));
    }

    /**
     * getHWBoard: get the model of Raspberry Pi board
     *
     * @return String with the model of Raspberry
     */
    public static String getHWBoard() {
        StringBuilder sb = new StringBuilder();
        try {
            sb.append(SystemInfo.getBoardType().name());
        } catch (IOException | InterruptedException | UnsupportedOperationException ex) {
            logger.error("Error getting type of board!!\n " + ex.getMessage());
        }
        return sb.toString();
    }

    /**
     * getAddress: return the URL address of server with specified name
     *
     * @param server server to search
     *
     * @return he URL of the server in format: http://ip_address:port
     */
    public static String getAddress(Server server) {
        String address;
        address = Constants.PROTOCOL + server.getIpAddress() + ":" + server.getPort();
        return address;
    }

    /**
     * getAddress: return the URL address of server with specified position into
     * the client list of servers
     *
     * @param client Object client to search in.
     * @param pos position to search
     *
     * @return the URL of the server in format: http://ip_address:port
     */
    public static String getAddress(Client client, int pos) {
        String address;
        address = Constants.PROTOCOL + client.getServer(pos).getIpAddress() + ":" + client.getServer(pos).getPort();
        return address;
    }

    /**
     * inString: return true if string value is on array
     *
     * @param array Array of string to search in.
     * @param string String to search in the array.
     *
     * @return true if the string it's in the array of string
     */
    public static boolean inString(String array[], String string) {
        boolean inString;

        inString = false;
        for (String str : array) {
            if (string.equals(str)) {
                inString = true;
            }
        }
        return inString;
    }
}
