package piserver;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 * Communication: this class implements the communications methods.
 *
 * 
 */
public final class Communication {

    // Logger for logs and messages
    static final Logger logger = LogManager.getLogger(piserver.Communication.class.getName());

    /**
     * sendResponse: send a response, in reply to a request.
     *
     * @param code Code of the response.
     * @param response String with the response.
     * @param serverName String with the name of the server.
     * @param messageToClient Stream with the client.
     */
    public static void sendResponse(int code, String response, String serverName, DataOutputStream messageToClient) {
        // Declarations
        // Strings for http headers.
        String statusLine;
        String serverDetails;
        String contentLenghtLine;
        String contentType;

        // Initializations
        // Prepare the http headers
        serverDetails = "Pi Server <" + serverName + ">";
        contentType = "Content-Type: application/json; charset=utf-8" + "\r\n";
        if (code == Constants.HTTP_RESPONSE_CODE_OK) {
            statusLine = "HTTP/1.1 200 OK" + "\r\n";
        } else {
            statusLine = "HTTP/1.1 404 Not found" + "\r\n";
        }
        contentLenghtLine = "Content-Lenght: " + response.length() + "\r\n";
        try {
            // Send meessage
            messageToClient.writeBytes(statusLine);
            messageToClient.writeBytes(serverDetails);
            messageToClient.writeBytes(contentType);
            messageToClient.writeBytes(contentLenghtLine);
            messageToClient.writeBytes("Connection: closed \r\n");
            messageToClient.writeBytes("\r\n");
            messageToClient.writeBytes(response);
            messageToClient.close();
            logger.trace("Response sent!!");
        } catch (IOException ioe) {
            logger.warn("Error sending response: " + response);
            logger.warn(ioe.getMessage());
        }
    }
}
