package piserver;

/**
 * Constants: class with all constants for all the methods
 *
 *
 */
public final class Constants {

    /**
     ********************************************************
     *
     * Constants
     *
     ********************************************************
     */
    public static final String USER_AGENT = "PiSolar/1.0"; // Mozilla/5.0
    public static final String PROTOCOL = "http://";

    /**
     * PATH: Path for search the configuration files
     */
    public static final String CONFIG_PATH = "/home/pi/.config/piSolar/";
    public static final String PATH = "/home/pi/";

    // Name of the files with the configurations
    public static final String SERVER_CONFIG_FILENAME = "rpi.config";
    public static final String RULES_CONFIG_FILENAME = "rules.config";
    public static final String CONFIG_LOG_PROPERTIES_XML = "log4j2.xml";

    // Some constans for work with resistances
    public static final int OMH = 1; // 1 Omhio
    public static final int KOMH = 1000 * OMH; // 1KOmhio
    public static final int MOMH = 1000 * KOMH; // 1MOmhio

    // Name of temperature sensors
    public static final String SENSOR_TEMP_SOLAR = "SensorT"; // Temperature of termoshiphon
    public static final String SENSOR_TEMP_EXT = "SensorE"; // Exterior temperature
    public static final String SENSOR_TEMP_AUX = "SensorA"; // Name of sensor of auxiliar thermo-accumulator

    // Name of the display LED sensors
    public static final String DISPLAY_TEMP_SOLAR = "LedT"; // Name of display to show the solar temp
    public static final String DISPLAY_TEMP_EXT = "LedE";

    /**
     * Enumerator with the connection errors
     */
    public static enum CONNECTION_ERROR {
        NO_ERROR,
        TIMEOUT_ERROR,
        IO_ERROR,
        POST_ERROR,
        GET_ERROR,
        COMMAND_ERROR
    }

    /**
     * HTTP_RESPONSE_CODE_OK: Standard code for correct request.
     */
    public static final int HTTP_RESPONSE_CODE_OK = 200;

    
    /**
     * Constants for I2C Devices
     *
     * ********************************************************************************
     */
    /**
     * ADS1115 ADC Data configuration
     */
    public static final short ADS1115_CONVERSION_REGISTER = 0x00; // Address of conversion register
    public static final short ADS1115_CONFIG_REGISTER = 0x01; // Address of cofiguration register
    public static final short ADS1115_NUMBER_SAMPLES = 30; // Number of samples to read
    public static final int ADS1115_RESOLUTION = 32768; // 2¹⁵bits
    public static final double ADS1115_GAIN = 2.048; // Configured in the config value, but used for calculate

    // Some electronic & temperature constans
    public static final double PI_VOLTAGE = 3.3; // 3.3V
    public static final double KELVIN_DEGREE = 273.15;

    /**
     * NTC_VALUES[][]: Array of strings with the values of NTC thermistors
     */
    public static final String[][] NTC_VALUES = {
        {"NTC1", // Name of the conversion for the NTC Thermistor for Sensor T
            "10000", // 10K - Value of resistance Rated Zero Power at temperature nominal (in Ohm)
            "25", // Value of temp nominal in ºC
            "3435", // Beta coefficient of the thermistor
            "20002"}, // 20K - Serial resistance for calcule the resistance of NTC thermistor (readed with tester)
        {"NTC2", // Idem for NTC Thermistor for sensor 2
            "10000",
            "25",
            "3950",
            "19966"}};

    /**
     * Display LED Names
     */
    // This array assign a display to a sensor
    public static final String[][] DISPLAY_LCD_NAMES = {
        {DISPLAY_TEMP_SOLAR,
            SENSOR_TEMP_SOLAR},
        {DISPLAY_TEMP_EXT,
            SENSOR_TEMP_EXT}};

    /**
     * AUTONOMOUS_SENSORS: Array with the names of the sensors to test in the autonomous mode.
     */
    public static final String[] AUTONOMOUS_SENSORS = {
        SENSOR_TEMP_SOLAR,
        SENSOR_TEMP_AUX
    };

    /**
     * OPTIMAL_TEMPERATURE_STRING: String used in the rules for indicate the optimal temperature.
     */
    public static final String OPTIMAL_TEMPERATURE_STRING = "TOptimal";
}
