package piserver;

import java.util.Calendar;
import java.util.Date;

/**
 * This class implement the values of a device
 *
 * 
 */
public class Device {

    // Attributes
    private String name; // Name
    private String mode; // Pin mode: IN, OUT, I2C,...

    private String parameter2;
    /*
     * If it's a GPÎO, this parameter store the Physical Pin number
     * If it's a IC2 device, this parameter is the hex address of bus I2C
     */

    private String parameter3;
    /*
     * If it's a GPIO, this parameter store the WiringPi & Pi4J logic pin number.
     * If it's a I2C device, store the name of I2C Device
     */

    private String parameter4;
    /*
     * If it's a GPIO, this parameter store the Logical Pin Name
     * If it's a I2C device, store the values of configuration register/s
     */

    private String parameter5;
    /*
     * If it's a GPIO, this parameter store the Logic Level of signal: HIGH or LOW
     * If it's a I2C device, store the used channel, or UNK
     */

    private String parameter6;
    /*
     * If it's a GPIO, this parameter store default or desired value on start: ON or OFF
     * If it's a I2C device, store the name of the conversion, or UNK
     */

    private String comment; // Comment
    private String value;
    /**
     * Value of device.
     * If it's a OUT device, it's the value send to the device.
     * If it's a IN device, it's the value read from the device.
     *
     */
    private String lastCommand;
    private Date lastDate;

    /**
     * Device constructor
     */
    public Device() {
        mode = "UNDEFINED";
        name = "";
        parameter2 = "";
        parameter3 = "";
        comment = "";
        parameter4 = "";
        value = "";
        this.lastCommand = "STARTUP SYSTEM";
        this.lastDate = Calendar.getInstance().getTime();
    }

    /**
     * getName: return the name of the device
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * setName: set the name of the device
     *
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * getMode: return the mode of the device (IN, OUT, I2C,.)
     *
     * @return the mode
     */
    public String getMode() {
        return mode;
    }

    /**
     * setMode: set the mode of the device (IN, OUT, I2C,.)
     *
     * @param modeStr String with the mode.
     */
    public void setMode(String modeStr) {
        this.mode = modeStr;
    }

    /**
     * getValue: return the value of the device
     *
     * @return the value
     */
    public String getValue() {
        return value;
    }

    /**
     * setValue: set the value of the device
     *
     * @param value the value to set
     */
    public void setValue(String value) {
        this.value = value;
    }

    /**
     * getComment: return the comment of the device
     *
     * @return the comment
     */
    public String getComment() {
        return comment;
    }

    /**
     * setComment: set the comment of the device
     *
     * @param comment the comment to set
     */
    public void setComment(String comment) {
        this.comment = comment.trim();
    }

    /**
     * getParameter2:
     *
     * If it's a GPIO, this method return the Physical Pin number
     * If it's a IC2 device, this method return the hex address of bus I2C
     *
     * @return the Physical Pin number or the address of bus I2C
     */
    public String getParameter2() {
        return parameter2;
    }

    /**
     * setParameter2:
     *
     * If it's a GPIO, this method set the Physical Pin number
     * If it's a IC2 device, this method set the hex address of bus I2C
     *
     * @param parameter2 the parameter2 to set
     */
    public void setParameter2(String parameter2) {
        this.parameter2 = parameter2;
    }

    /**
     * getParameter3:
     *
     * If it's a GPIO, return the WiringPi and Pi4J logic pin number.
     * If it's a I2C device, return the name of I2C Device
     *
     * @return the pi4jPin or the I2C Device name
     */
    public String getParameter3() {
        return parameter3;
    }

    /**
     * setParameter3:
     *
     * If it's a GPIO, set the WiringPi and Pi4J logic pin number.
     * If it's a I2C device, store the name of I2C Device
     *
     * @param pi4jPin the pi4jPin to set
     */
    public void setParameter3(String pi4jPin) {
        this.parameter3 = pi4jPin;
    }

    /**
     * getParameter4:
     *
     * If it's a GPIO, return the Logical Pin Name
     * If it's a I2C device, return the values of configuration register/s
     *
     * @return the parameter4
     */
    public String getParameter4() {
        return parameter4;
    }

    /**
     * setParameter4:
     *
     * If it's a GPIO, this parameter store the Logical Pin Name
     * If it's a I2C device, store the values of configuration register/s
     *
     * @param parameter4 the parameter4 to set
     */
    public void setParameter4(String parameter4) {
        this.parameter4 = parameter4;
    }

    /**
     * getLastCommand: return the last command executed on the device
     *
     * @return the lastCommand
     */
    public String getLastCommand() {
        return lastCommand;
    }

    /**
     * setLastCommand: set the last command executed on device
     *
     * @param lastCommand the lastCommand to set
     */
    public void setLastCommand(String lastCommand) {
        this.lastCommand = lastCommand;
    }

    /**
     * getLastDate: return the last date on that a command was executed on this device
     *
     * @return the lastDate
     */
    public Date getLastDate() {
        return lastDate;
    }

    /**
     * setLastDate: set the current date, date on that a command was executed on this device
     *
     */
    public void setLastDate() {
        this.lastDate = Calendar.getInstance().getTime();
    }

    /**
     * setLastDate: set the date on that a command was executed on this device. 
     *
     * @param lastDate Timestamp.
     */
    public void setLastDate(Date lastDate) {
        this.lastDate = lastDate;
    }

    /**
     * getParameter5:
     *
     * If it's a GPIO, return the Logic Level of signal: HIGH or LOW
     * If it's a I2C device, return the used channel, or UNK
     *
     * @return the parameter5
     *
     */
    public String getParameter5() {
        return parameter5;
    }

    /**
     * setParameter5:
     *
     * If it's a GPIO, this parameter store the Logic Level of signal: HIGH or LOW
     * If it's a I2C device, store the used channel, or UNK
     *
     * @param parameter5 the parameter5 to set
     */
    public void setParameter5(String parameter5) {
        this.parameter5 = parameter5;
    }

    /**
     * getParameter6:
     *
     * If it's a GPIO, return the default or desired value on start: ON or OFF
     * If it's a I2C device, return the name of the conversion, or UNK
     *
     * @return the parameter6
     *
     */
    public String getParameter6() {
        return parameter6;
    }

    /**
     * setParameter6:
     *
     * If it's a GPIO, this parameter store default or desired value on start: ON or OFF
     * If it's a I2C device, store the name of the conversion, or UNK
     *
     * @param parameter6 the parameter6 to set
     */
    public void setParameter6(String parameter6) {
        this.parameter6 = parameter6;
    }

    /**
     * toString:
     *
     * @return String with the device configuration.
     */
    @Override
    public String toString() {
        StringBuilder str = new StringBuilder();
        str.append("Name:           ").append(getName()).append("\n");
        str.append("Mode:           ").append(getMode()).append("\n");
        str.append("Physical Pin:   ").append(getParameter2()).append("\n");
        str.append("Pi4J Pin:       ").append(getParameter3()).append("\n");
        str.append("Logic Pin Name: ").append(getParameter4()).append("\n");
        str.append("Default value:  ").append(getParameter6()).append("\n");
        str.append("Value:          ").append(getValue()).append("\n");
        str.append("Last command:   ").append(getLastCommand()).append("\n");
        str.append("Last date:      ").append(getLastDate()).append("\n");
        str.append("Comment:        ").append(getComment()).append("\n");
        return str.toString();
    }
}
