package piserver;

import com.pi4j.io.i2c.I2CDevice;
import java.text.DecimalFormat;
import java.util.TimerTask;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 *
 * 
 */
public class GetTempTask extends TimerTask {

    Server server;
    Raspberry rpi;

    // Logger for logs and messages
    static final Logger logger = LogManager.getLogger(piserver.Communication.class.getName());

    GetTempTask(Server server, Raspberry rpi) {
        this.server = server;
        this.rpi = rpi;
    }

    @Override
    public void run() {
        // Declarations
        String tempStr; // Temperature
        Double temp;
        Device device; //  Device
        I2CDevice adafruitFeather; // I2C Device identifier
        String lcd; // Name of the display
        String sensor; // Name of the sensor

        for (String[] array : Constants.DISPLAY_LCD_NAMES) {
            // Get the LED Display name.
            lcd = array[0];
            // Get the sensor name.
            sensor = array[1];
            // Get the device with that sensor.
            device = server.getDevice(sensor);
            // Get the themperature
            tempStr = device.getValue();
            try {
                temp = Double.parseDouble(tempStr);
                DecimalFormat df = new DecimalFormat("0.00");
                tempStr = "0000" + ((df.format(temp)));
                tempStr = Utilities.right(tempStr, 5);
                // Send it to a I2C LCD Display
                adafruitFeather = rpi.getI2CDeviceFromMap(lcd); // Get the I2C device
                I2CDisplay.displayLED(adafruitFeather, tempStr); // Show temp on display
                logger.trace(sensor + " >> " + tempStr);
            } catch (NumberFormatException nfe) {
                logger.error("Error reading temperature... \n" + nfe.getStackTrace().toString());
            }

        }
    }
}
