package piserver;

import java.util.ArrayList;

/**
 * ServerStatus: this class extends the Server with the parameters necessary to operate in
 * autonomous mode.
 *
 * This class store the last and the current status, the temperatures and the rules to use in autonomous mode.
 *
 */
public class ServerStatus extends Server {

    private Status lastStatus; // Previous status
    private Status currentStatus; // Current status
    private double optimalTemp; // Optimal temperature 
    private ArrayList<AutonomousRule> listRules; // List of rules.

    // Constructor
    public ServerStatus() {
        this.lastStatus = null;
        this.currentStatus = null;
        this.optimalTemp = 0.0;
        this.listRules = new ArrayList<>();
    }

    /**
     * getLastStatus: return the last global status.
     *
     * @return the lastStatus
     */
    public Status getLastStatus() {
        return lastStatus;
    }

    /**
     * setLastStatus: set the last global status.
     *
     * @param lastStatus the lastStatus to set
     */
    public void setLastStatus(Status lastStatus) {
        this.lastStatus = lastStatus;
    }

    /**
     * getCurrentStatus: return the current status.
     *
     * @return the currentStatus
     */
    public Status getCurrentStatus() {
        return currentStatus;
    }

    /**
     * setCurrentStatus: set the current status.
     *
     * @param currentStatus the currentStatus to set
     */
    public void setCurrentStatus(Status currentStatus) {
        this.currentStatus = currentStatus;
    }

    /**
     * exchangeStatus: this method set the current status as last status, and the status passed
     * as parameter as the current status.
     *
     * @param newStatus New status to set as current status.
     */
    public void exchangeStatus(Status newStatus) {
        setLastStatus(getCurrentStatus());
        setCurrentStatus(newStatus);
    }

    /**
     * getOptimalTemp: Get the optimal temperature of thermosyphon water.
     *
     * @return the optimalTemp
     */
    public double getOptimalTemp() {
        return optimalTemp;
    }

    /**
     * setOptimalTemp: Set the optimal temperature of thermosyphon water.
     *
     * @param optimalTemp the optimalTemp to set
     */
    public void setOptimalTemp(double optimalTemp) {
        this.optimalTemp = optimalTemp;
    }

    /**
     * getListRules: get the list of rules.
     *
     * @return the listRules
     */
    public ArrayList<AutonomousRule> getListRules() {
        return listRules;
    }

    public AutonomousRule getListRules(int pos) {
        if (pos < this.listRules.size()) {
            return this.listRules.get(pos);
        }
        return null;
    }

    /**
     * SetListRules: set the list of rules.
     *
     * @param listRules the listRules to set
     */
    public void setListRules(ArrayList<AutonomousRule> listRules) {
        this.listRules = listRules;
    }

    /**
     * addListRules: add a rule to the list of rules.
     *
     * @param rule to add
     */
    public void addListRules(AutonomousRule rule) {
        this.listRules.add(rule);
    }

}
